@@ -621,6 +621,7 @@ bool Event::SetPath(Storage *storage) {
 }  // end bool Event::SetPath
 
 void Event::Run() {
+  Debug(1, "Starting event thread");
   Storage *storage = monitor->getStorage();
   if (!SetPath(storage)) {
     // Try another
@@ -721,11 +722,10 @@ void Event::Run() {
       std::unique_lock<std::mutex> lck(packet_queue_mutex);
 
       if (packet_queue.empty()) {
-        if (!(terminate_ or zm_terminate))
-          packet_queue_condition.wait(lck);
-        // Neccessary because we don't hold the lock in the while condition
         if (terminate_ or zm_terminate) break;
+        packet_queue_condition.wait(lck);
       } 
+
       if (!packet_queue.empty()) {
         // Packets on this queue are locked. They are locked by analysis thread
         packet_lock = packet_queue.front();
@@ -733,6 +733,7 @@ void Event::Run() {
       }
     }  // end lock scope
     if (packet_lock) {
+      Debug(1, "Adding packet %d", packet_lock->packet_->image_index);
       this->AddPacket_(packet_lock->packet_);
       delete packet_lock;
     }
