@@ -130,7 +130,7 @@ bool PacketQueue::queuePacket(std::shared_ptr<ZMPacket> add_packet) {
 
         ZMLockedPacket lp(zm_packet);
         if (!lp.trylock()) {
-          if (warned_count <2) {
+          if (warned_count < 2) {
             warned_count++;
             // Can't delete a locked packet, but can delete one after it.
             Warning("Found locked packet when trying to free up video packets. This basically means that decoding is not keeping up.");
@@ -166,7 +166,7 @@ bool PacketQueue::queuePacket(std::shared_ptr<ZMPacket> add_packet) {
         if (zm_packet->packet.stream_index == video_stream_id)
           break;
       }  // end while
-    } else {
+    } else if (warned_count > 0) {
       warned_count--;
     }  // end if not able catch up
   }  // end lock scope
@@ -227,7 +227,10 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
     while ((*pktQueue.begin() != add_packet) and (packet_counts[video_stream_id] > pre_event_video_packet_count + tail_count)) {
       std::shared_ptr<ZMPacket> zm_packet = *pktQueue.begin();
       ZMLockedPacket *lp = new ZMLockedPacket(zm_packet);
-      if (!lp->trylock()) break;
+      if (!lp->trylock()) {
+        delete lp;
+        break;
+      }
       delete lp;
 
       if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
@@ -245,7 +248,6 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
             packet_counts[video_stream_id],
             pre_event_video_packet_count,
             pktQueue.size());
-      //delete zm_packet;
     } // end while
     return;
   }
@@ -256,58 +258,70 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
   // First packet is special because we know it is a video keyframe and only need to check for lock
   std::shared_ptr<ZMPacket> zm_packet = *it;
   if (zm_packet == add_packet) {
+    Debug(1, "First packet in queue is the analysis packet.");
     return;
   }
 
   ZMLockedPacket *lp = new ZMLockedPacket(zm_packet);
-  if (lp->trylock()) {
-    int keyframe_interval = 1;
-    int video_packets_to_delete = 0;    // This is a count of how many packets we will delete so we know when to stop looking
-    Debug(4, "Have lock on first packet");
-    ++it;
+  if (!lp->trylock()) {
+    Debug(4, "Failed getting lock on first packet");
+    delete lp;
+    return;
+  }  // end if first packet not locked
+     
+  int keyframe_interval = 1;
+  int video_packets_to_delete = 0;    // This is a count of how many packets we will delete so we know when to stop looking
+  ++it;
+  delete lp;
+
+  // Since we have many packets in the queue, we should NOT be pointing at end so don't need to test for that
+  while (*it != add_packet) {
+    zm_packet = *it;
+    lp = new ZMLockedPacket(zm_packet);
+    if (!lp->trylock()) {
+      Debug(3, "Failed locking packet %d", zm_packet->image_index);
+      delete lp;
+      break;
+    }
     delete lp;
 
-    // Since we have many packets in the queue, we should NOT be pointing at end so don't need to test for that
-    while (*it != add_packet) {
-      zm_packet = *it;
-      lp = new ZMLockedPacket(zm_packet);
-      if (!lp->trylock()) {
-        Debug(3, "Failed locking packet %d", zm_packet->image_index);
-        delete lp;
-        break;
-      }
-      delete lp;
-
 #if 0
-      // There are no threads that follow analysis thread.  So there cannot be an it pointing here
-      if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
-        if (pktQueue.begin() == next_front)
-          Warning("Found iterator at beginning of queue. Some thread isn't keeping up");
-        break;
-      }
+    // There are no threads that follow analysis thread.  So there cannot be an it pointing here
+    // event writing thread technically follows, but packets are copied out of queue
+    if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
+      if (pktQueue.begin() == next_front)
+        Warning("Found iterator at beginning of queue. Some thread isn't keeping up");
+      break;
+    }
 #endif
 
-      if (zm_packet->packet.stream_index == video_stream_id) {
-        if (zm_packet->keyframe) {
-          Debug(1, "Have a video keyframe so setting next front to it. Keyframe interval so far is %d", keyframe_interval);
-          keyframe_interval = 1;
-          next_front = it;
-        } else {
-          keyframe_interval++;
-        }
-        ++video_packets_to_delete;
+    if (zm_packet->packet.stream_index == video_stream_id) {
+      if (zm_packet->keyframe) {
+        Debug(4, "Have a video keyframe so setting next front to it. Keyframe interval so far is %d", keyframe_interval);
+        keyframe_interval = 1;
+        next_front = it;
+      } else {
+        keyframe_interval++;
+      }
+      ++video_packets_to_delete;
+      if (packet_counts[video_stream_id] - video_packets_to_delete <= pre_event_video_packet_count + tail_count) {
         Debug(3, "Counted %d video packets. Which would leave %d in packetqueue tail count is %d",
             video_packets_to_delete, packet_counts[video_stream_id]-video_packets_to_delete, tail_count);
-        if (packet_counts[video_stream_id] - video_packets_to_delete <= pre_event_video_packet_count + tail_count) {
-          break;
-        }
+        break;
       }
-      ++it;
     } // end while
+    ++it;
   }  // end if first packet not locked
-  Debug(1, "Resulting it pointing at latest packet? %d, next front points to begin? %d",
+
+  if ((keyframe_interval == 1) and max_video_packet_count) {
+    Warning("Did not find a second keyframe in the packet queue. It may be that"
+        " the Max Image Buffer setting is lower than the keyframe interval. We"
+        " need it to be greater than the keyframe interval.");
+  }
+  Debug(1, "Resulting it pointing at latest packet? %d, next front points to begin? %d, Keyframe interval %d",
       ( *it == add_packet ),
-      ( next_front == pktQueue.begin() )
+      ( next_front == pktQueue.begin() ),
+      keyframe_interval
       );
   if (next_front != pktQueue.begin()) {
     while (pktQueue.begin() != next_front) {
@@ -329,7 +343,6 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
       packet_counts[zm_packet->packet.stream_index] -= 1;
     }
   }  // end if have at least max_video_packet_count video packets remaining
-  // We signal on every packet because someday we may analyze sound
 
 	return;
 } // end voidPacketQueue::clearPackets(ZMPacket* zm_packet)
@@ -337,6 +350,7 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
 void PacketQueue::stop() {
   deleting = true;
   condition.notify_all();
+  for (const auto p : pktQueue) p->notify_all();
 }
 
 void PacketQueue::clear() {
@@ -375,7 +389,7 @@ void PacketQueue::clear() {
     *iterator_it = pktQueue.begin();
   }  // end foreach iterator
 
-  if (packet_counts) delete[] packet_counts;
+  delete[] packet_counts;
   packet_counts = nullptr;
   max_stream_id = -1;
 
@@ -538,16 +552,18 @@ packetqueue_iterator *PacketQueue::get_event_start_packet_it(
 
   *it = snapshot_it;
   std::shared_ptr<ZMPacket> packet = *(*it);
-  ZM_DUMP_PACKET(packet->packet, "");
+  //ZM_DUMP_PACKET(packet->packet, "");
   // Step one count back pre_event_count frames as the minimum
   // Do not assume that snapshot_it is video
   // snapshot it might already point to the beginning
   if (pre_event_count) {
     while ((*it) != pktQueue.begin()) {
       packet = *(*it);
+      /*
       Debug(1, "Previous packet pre_event_count %d stream_index %d keyframe %d score %d",
           pre_event_count, packet->packet.stream_index, packet->keyframe, packet->score);
       ZM_DUMP_PACKET(packet->packet, "");
+      */
       if (packet->packet.stream_index == video_stream_id) {
         pre_event_count --;
         if (!pre_event_count)
@@ -566,7 +582,7 @@ packetqueue_iterator *PacketQueue::get_event_start_packet_it(
     } else {
       Warning("Hit end of packetqueue before satisfying pre_event_count. Needed %d more video frames", pre_event_count);
     }
-    ZM_DUMP_PACKET(packet->packet, "");
+    //ZM_DUMP_PACKET(packet->packet, "");
     return it;
   } else if (!keep_keyframes) {
     // Are encoding, so don't care about keyframes
@@ -575,7 +591,7 @@ packetqueue_iterator *PacketQueue::get_event_start_packet_it(
 
   while ((*it) != pktQueue.begin()) {
     packet = *(*it);
-    ZM_DUMP_PACKET(packet->packet, "No keyframe");
+    //ZM_DUMP_PACKET(packet->packet, "No keyframe");
     if ((packet->packet.stream_index == video_stream_id) and packet->keyframe)
       return it; // Success
     --(*it);
@@ -632,7 +648,7 @@ packetqueue_iterator * PacketQueue::get_video_it(bool wait) {
     }
     ++(*it);
   }
-  Debug(1, "DIdn't Found a keyframe for stream %d, so returning the it to it", video_stream_id);
+  Debug(1, "Didn't find a keyframe for stream %d, so returning the it to it", video_stream_id);
   return it;
 }  // get video_it
 
