@@ -48,6 +48,7 @@ function migrateHash($user, $pass) {
     //ZM\Info ("hased bcrypt $pass is $bcrypt_hash");
     $update_password_sql = 'UPDATE Users SET Password=\''.$bcrypt_hash.'\' WHERE Username=\''.$user.'\'';
     dbQuery($update_password_sql);
+    $user['Pasword'] = $bcrypt_hash;
     # Since password field has changed, existing auth_hash is no longer valid
     generateAuthHash(ZM_AUTH_HASH_IPS, true);
   } else {
@@ -127,8 +128,6 @@ function validateToken($token, $allowed_token_type='access') {
       ZM\Error("Token type mismatch. Expected $allowed_token_type but got $type");
       return array(false, 'Incorrect token type');
     }
-  } else {
-    ZM\Debug('Not comparing token types as [any] was passed');
   }
   
   $username = $jwt_payload['user'];
