@@ -39,10 +39,10 @@ if ( $user['MonitorIds'] ) {
 }
 $Monitor = $Event->Monitor();
 
-if ( isset($_REQUEST['rate']) ) {
+if (isset($_REQUEST['rate'])) {
   $rate = validInt($_REQUEST['rate']);
-} else if ( isset($_COOKIE['zmEventRate']) ) {
-  $rate = $_COOKIE['zmEventRate'];
+} else if (isset($_COOKIE['zmEventRate'])) {
+  $rate = validInt($_COOKIE['zmEventRate']);
 } else {
   $rate = reScale(RATE_BASE, $Monitor->DefaultRate(), ZM_WEB_DEFAULT_RATE);
 }
@@ -149,13 +149,12 @@ if ( $Event->Id() and !file_exists($Event->Path()) )
         <button id="unarchiveBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Unarchive') ?>" disabled><i class="fa fa-file-archive-o"></i></button>
         <button id="editBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Edit') ?>" disabled><i class="fa fa-pencil"></i></button>
         <button id="exportBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Export') ?>"><i class="fa fa-external-link"></i></button>
-<?php
-  if ( $Event->DefaultVideo() ) {
-?>
-        <a class="btn btn-normal" href="<?php echo $Event->getStreamSrc(array('mode'=>'mp4'),'&amp;')?>" download><i class="fa fa-download"></i></a>
-<?php
-  } 
-?>
+        <a id="downloadBtn" class="btn btn-normal" href="<?php echo $Event->getStreamSrc(array('mode'=>'mp4'),'&amp;')?>"
+          title="<?php echo translate('Download'). ' ' . $Event->DefaultVideo() ?>"
+          download
+          <?php echo $Event->DefaultVideo() ? '' : 'style="display:none;"' ?>
+><i class="fa fa-download"></i></a>
+        <button id="videoBtn" class="btn btn-normal" data-toggle="tooltip" data-toggle="tooltip" data-placement="top" title="<?php echo translate('GenerateVideo') ?>"><i class="fa fa-file-video-o"></i></button>
         <button id="statsBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Stats') ?>" ><i class="fa fa-info"></i></button>
         <button id="framesBtn" class="btn btn-normal" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Frames') ?>" ><i class="fa fa-picture-o"></i></button>
         <button id="deleteBtn" class="btn btn-danger" data-toggle="tooltip" data-placement="top" title="<?php echo translate('Delete') ?>"><i class="fa fa-trash"></i></button>
@@ -272,7 +271,6 @@ if ( (ZM_WEB_STREAM_METHOD == 'mpeg') && ZM_MPEG_LIVE_FORMAT ) {
 #rates are defined in skins/classic/includes/config.php
 echo htmlSelect('rate', $rates, intval($rate), array('id'=>'rateValue'));
 ?>
-<!--<span id="rateValue"><?php echo $rate/100 ?></span>x</span>-->
           <span id="progress"><?php echo translate('Progress') ?>: <span id="progressValue">0</span>s</span>
           <span id="zoom"><?php echo translate('Zoom') ?>: <span id="zoomValue">1</span>x</span>
         </div>
