@@ -28,7 +28,7 @@ var zmsBroke = false; //Use alternate navigation if zms has crashed
 var wasHidden = false;
 
 function streamReq(data) {
-  if ( auth_hash ) data.auth = auth_hash;
+  if (auth_hash) data.auth = auth_hash;
   data.connkey = connKey;
   data.view = 'request';
   data.request = 'stream';
@@ -303,11 +303,7 @@ function getCmdResponse(respObj, respText) {
   updateProgressBar();
 
   if (streamStatus.auth) {
-    // Try to reload the image stream.
-    var streamImg = document.getElementById('evtStream');
-    if (streamImg) {
-      streamImg.src = streamImg.src.replace(/auth=\w+/i, 'auth='+streamStatus.auth);
-    }
+    auth_hash = streamStatus.auth;
   } // end if haev a new auth hash
 
   streamCmdTimer = setTimeout(streamQuery, streamTimeout); //Timeout is refresh rate for progressBox and time display
@@ -450,6 +446,7 @@ function streamFastRev(action) {
 function streamPrev(action) {
   if (action) {
     $j(".vjsMessage").remove();
+    if (vid==null) streamReq({command: CMD_QUIT});
     location.replace(thisUrl + '?view=event&eid=' + prevEventId + filterQuery + sortQuery);
     return;
 
@@ -484,6 +481,7 @@ function streamNext(action) {
   // We used to try to dynamically update all the bits in the page, which is really complex
   // How about we just reload the page?
   //
+  if (vid==null) streamReq({command: CMD_QUIT});
   location.replace(thisUrl + '?view=event&eid=' + nextEventId + filterQuery + sortQuery);
   return;
   if (vid && ( NextEventDefVideoPath.indexOf('view_video') > 0 )) {
